=======
Credits
=======

Development Lead
----------------

* Kalyakulina Alena <kalyakulina.alena@gmail.com>
* Yusipov Igor <yusipov.igor@gmail.com>

Contributors
------------

None yet. Why not be the first?
